@@ -20,7 +20,7 @@ coxUI <- function(id) {
     uiOutput(ns("rangetime")),
     uiOutput(ns("indep")),
     sliderInput(ns("decimal"), "Digits",
-                min = 1, max = 4, value = 2
+      min = 1, max = 4, value = 2
     ),
     checkboxInput(ns("subcheck"), "Sub-group analysis"),
     uiOutput(ns("subvar")),
@@ -158,12 +158,12 @@ coxModule <- function(input, output, session, data, data_label, data_varStruct =
 
     tagList(
       selectInput(session$ns("event_cox"), "Event",
-                  choices = mklist(data_varStruct(), vlist()$factor_01vars), multiple = F,
-                  selected = NULL
+        choices = mklist(data_varStruct(), vlist()$factor_01vars), multiple = F,
+        selected = NULL
       ),
       selectInput(session$ns("time_cox"), "Time",
-                  choices = mklist(data_varStruct(), vlist()$conti_vars_positive), multiple = F,
-                  selected = NULL
+        choices = mklist(data_varStruct(), vlist()$conti_vars_positive), multiple = F,
+        selected = NULL
       )
     )
   })
@@ -177,11 +177,13 @@ coxModule <- function(input, output, session, data, data_label, data_varStruct =
       )
       tagList(
         selectInput(session$ns("cmp_event_cox"), "Competing Event",
-                    choices = mklist(data_varStruct(), vlist()$factor_01vars), multiple = FALSE,
-                    selected = NULL),
+          choices = mklist(data_varStruct(), vlist()$factor_01vars), multiple = FALSE,
+          selected = NULL
+        ),
         selectInput(session$ns("cmp_time_cox"), "Competing Time",
-                    choices = mklist(data_varStruct(), vlist()$conti_vars_positive), multiple = FALSE,
-                    selected = NULL)
+          choices = mklist(data_varStruct(), vlist()$conti_vars_positive), multiple = FALSE,
+          selected = NULL
+        )
       )
     })
   })
@@ -190,8 +192,8 @@ coxModule <- function(input, output, session, data, data_label, data_varStruct =
     output$rangetime <- renderUI({
       req(input$check_rangetime == T)
       sliderInput(session$ns("range_time"), "Time ranges",
-                  min = min(data()[[input$time_cox]], na.rm = T), max = max(data()[[input$time_cox]], na.rm = T),
-                  value = c(min(data()[[input$time_cox]], na.rm = T), median(data()[[input$time_cox]], na.rm = T))
+        min = min(data()[[input$time_cox]], na.rm = T), max = max(data()[[input$time_cox]], na.rm = T),
+        value = c(min(data()[[input$time_cox]], na.rm = T), median(data()[[input$time_cox]], na.rm = T))
       )
     })
   })
@@ -290,8 +292,8 @@ coxModule <- function(input, output, session, data, data_label, data_varStruct =
 
     tagList(
       selectInput(session$ns("indep_cox"), "Independent variables",
-                  choices = mklist(data_varStruct(), indep.cox), multiple = T,
-                  selected = indep.cox[varsIni]
+        choices = mklist(data_varStruct(), indep.cox), multiple = T,
+        selected = indep.cox[varsIni]
       )
     )
   })
@@ -314,8 +316,8 @@ coxModule <- function(input, output, session, data, data_label, data_varStruct =
 
       tagList(
         selectInput(session$ns("subvar_cox"), "Sub-group variables",
-                    choices = var_subgroup_list, multiple = T,
-                    selected = var_subgroup[1]
+          choices = var_subgroup_list, multiple = T,
+          selected = var_subgroup[1]
         )
       )
     })
@@ -331,14 +333,14 @@ coxModule <- function(input, output, session, data, data_label, data_varStruct =
     for (v in seq_along(input$subvar_cox)) {
       if (input$subvar_cox[[v]] %in% vlist()$factor_vars) {
         outUI[[v]] <- selectInput(session$ns(paste0("subval_cox", v)), paste0("Sub-group value: ", input$subvar_cox[[v]]),
-                                  choices = data_label()[variable == input$subvar_cox[[v]], level], multiple = T,
-                                  selected = data_label()[variable == input$subvar_cox[[v]], level][1]
+          choices = data_label()[variable == input$subvar_cox[[v]], level], multiple = T,
+          selected = data_label()[variable == input$subvar_cox[[v]], level][1]
         )
       } else {
         val <- stats::quantile(data()[[input$subvar_cox[[v]]]], na.rm = T)
         outUI[[v]] <- sliderInput(session$ns(paste0("subval_cox", v)), paste0("Sub-group range: ", input$subvar_cox[[v]]),
-                                  min = val[1], max = val[5],
-                                  value = c(val[2], val[4])
+          min = val[1], max = val[5],
+          value = c(val[2], val[4])
         )
       }
     }
@@ -377,8 +379,7 @@ coxModule <- function(input, output, session, data, data_label, data_varStruct =
         "survival::Surv(fgstart, fgstop, fgstatus) ~ ",
         paste(input$indep_cox, collapse = "+")
       ))
-    }
-    else{
+    } else {
       if (is.null(id.cluster)) {
         return(as.formula(paste("survival::Surv(", input$time_cox, ",", input$event_cox, ") ~ ", paste(input$indep_cox, collapse = "+"), sep = "")))
       } else {
@@ -429,13 +430,13 @@ coxModule <- function(input, output, session, data, data_label, data_varStruct =
       req(input$cmp_time_cox)
       req(input$event_cox)
       req(input$time_cox)
-      data.cox[[input$cmp_event_cox]]<- as.numeric(as.vector(data.cox[[input$cmp_event_cox]]))
-      data.cox$cmpp_time <- with(data.cox, ifelse(data.cox[[input$event_cox]]==0, data.cox[[input$cmp_time_cox]], data.cox[[input$time_cox]]))
-      data.cox$cmpp_event <- with(data.cox, ifelse(data.cox[[input$event_cox]]==0, 2*data.cox[[input$cmp_event_cox]],  1))
-      data.cox$cmpp_event<- factor(data.cox$cmpp_event)
-      fg_data <- survival::finegray(formula = survival::Surv(cmpp_time,cmpp_event) ~ ., data = data.cox)
-      data.cox<-data.table::data.table(fg_data)
-      cc <- substitute(survival::coxph(.form, data = data.cox, weight = fgwt,  model = T,  ties = .ties), list(.form = form.cox(), .ties = ties.coxph))
+      data.cox[[input$cmp_event_cox]] <- as.numeric(as.vector(data.cox[[input$cmp_event_cox]]))
+      data.cox$cmpp_time <- with(data.cox, ifelse(data.cox[[input$event_cox]] == 0, data.cox[[input$cmp_time_cox]], data.cox[[input$time_cox]]))
+      data.cox$cmpp_event <- with(data.cox, ifelse(data.cox[[input$event_cox]] == 0, 2 * data.cox[[input$cmp_event_cox]], 1))
+      data.cox$cmpp_event <- factor(data.cox$cmpp_event)
+      fg_data <- survival::finegray(formula = survival::Surv(cmpp_time, cmpp_event) ~ ., data = data.cox)
+      data.cox <- data.table::data.table(fg_data)
+      cc <- substitute(survival::coxph(.form, data = data.cox, weight = fgwt, model = T, ties = .ties), list(.form = form.cox(), .ties = ties.coxph))
     }
     mf <- model.frame(form.cox(), data.cox)
     validate(
@@ -446,9 +447,9 @@ coxModule <- function(input, output, session, data, data_label, data_varStruct =
       need(sum(lgl.1level) == 0, paste(paste(names(lgl.1level)[lgl.1level], collapse = " ,"), "has(have) a unique value. Please remove that from independent variables"))
     )
     if (is.null(design.survey)) {
-      if (is.null(id.cluster)&!input$cmp_risk_check) {
+      if (is.null(id.cluster) & !input$cmp_risk_check) {
         cc <- substitute(survival::coxph(.form, data = data.cox, model = T, ties = .ties), list(.form = form.cox(), .ties = ties.coxph))
-      } else if (!is.null(id.cluster)&!input$cmp_risk_check){
+      } else if (!is.null(id.cluster) & !input$cmp_risk_check) {
         cc <- substitute(survival::coxph(.form, data = data.cox, model = T, robust = T, ties = .ties), list(.form = form.cox(), .ties = ties.coxph))
       }
       res.cox <- eval(cc)
