@@ -320,11 +320,13 @@ kaplanModule <- function(input, output, session, data, data_label, data_varStruc
       )
       tagList(
         selectInput(session$ns("cmp_event_km"), "Competing Event",
-                    choices = mklist(data_varStruct(), vlist()$factor_01vars), multiple = FALSE,
-                    selected = NULL),
+          choices = mklist(data_varStruct(), vlist()$factor_01vars), multiple = FALSE,
+          selected = NULL
+        ),
         selectInput(session$ns("cmp_time_km"), "Competing Time",
-                    choices = mklist(data_varStruct(), vlist()$conti_vars_positive), multiple = FALSE,
-                    selected = NULL)
+          choices = mklist(data_varStruct(), vlist()$conti_vars_positive), multiple = FALSE,
+          selected = NULL
+        )
       )
     })
   })
@@ -493,12 +495,12 @@ kaplanModule <- function(input, output, session, data, data_label, data_varStruc
     data.km <- data()
     label.regress <- data_label()
     data.km[[input$event_km]] <- as.numeric(as.vector(data.km[[input$event_km]]))
-    if(input$cmp_risk_check){
+    if (input$cmp_risk_check) {
       req(!is.null(input$cmp_event_km))
       data.km[[input$cmp_event_km]] <- as.numeric(as.vector(data.km[[input$cmp_event_km]]))
-      data.km$cmpp_time <- with(data.km, ifelse(data.km[[input$event_km]]==0, data.km[[input$cmp_time_km]], data.km[[input$time_km]]))
-      data.km$cmpp_event <- with(data.km, ifelse(data.km[[input$event_km]]==0, 2*data.km[[input$cmp_event_km]],  1))
-      data.km$cmpp_event <- factor(data.km$cmpp_event, 0:2, labels=c("zero", "cmp", "cmprsk"))
+      data.km$cmpp_time <- with(data.km, ifelse(data.km[[input$event_km]] == 0, data.km[[input$cmp_time_km]], data.km[[input$time_km]]))
+      data.km$cmpp_event <- with(data.km, ifelse(data.km[[input$event_km]] == 0, 2 * data.km[[input$cmp_event_km]], 1))
+      data.km$cmpp_event <- factor(data.km$cmpp_event, 0:2, labels = c("zero", "cmp", "cmprsk"))
     }
     if (input$subcheck == T) {
       validate(
@@ -688,34 +690,32 @@ kaplanModule <- function(input, output, session, data, data_label, data_varStruc
     if (is.null(design.survey)) {
       status_cmprsk <- NULL
       if (input$cmp_risk_check) {
-        status_cmprsk <- 'cmp'
+        status_cmprsk <- "cmp"
       }
       if (is.null(id.cluster)) {
-        if(input$cmp_risk_check){
+        if (input$cmp_risk_check) {
           return(
             jskm::jskm(res.km,
-                       pval = input$pval, marks = input$marks, table = input$table, ylab = ylab, ystrataname = yst.name, ystratalabs = yst.lab, ci = input$ci, timeby = input$timeby, xlims = input$xlims, ylims = input$ylims,
-                       cumhaz = input$cumhaz, cluster.option = "None", cluster.var = NULL, data = data.km, pval.coord = pval.coord, legendposition = legend.p, linecols = pal, xlabs = text.x, dashed = dashed, cut.landmark = cut.landmark,
-                       showpercent = input$showpercent, surv.scale = surv.scale, status.cmprsk =  status_cmprsk
+              pval = input$pval, marks = input$marks, table = input$table, ylab = ylab, ystrataname = yst.name, ystratalabs = yst.lab, ci = input$ci, timeby = input$timeby, xlims = input$xlims, ylims = input$ylims,
+              cumhaz = input$cumhaz, cluster.option = "None", cluster.var = NULL, data = data.km, pval.coord = pval.coord, legendposition = legend.p, linecols = pal, xlabs = text.x, dashed = dashed, cut.landmark = cut.landmark,
+              showpercent = input$showpercent, surv.scale = surv.scale, status.cmprsk = status_cmprsk
             )
           )
-        }
-        else{
-        return(
+        } else {
+          return(
             jskm::jskm(res.km,
-                       pval = input$pval, marks = input$marks, table = input$table, ylab = ylab, ystrataname = yst.name, ystratalabs = yst.lab, ci = input$ci, timeby = input$timeby, xlims = input$xlims, ylims = input$ylims,
-                       cumhaz = input$cumhaz, cluster.option = "None", cluster.var = NULL, data = data.km, pval.coord = pval.coord, legendposition = legend.p, linecols = pal, xlabs = text.x, dashed = dashed, cut.landmark = cut.landmark,
-                       showpercent = input$showpercent, surv.scale = surv.scale, status.cmprsk =  status_cmprsk
+              pval = input$pval, marks = input$marks, table = input$table, ylab = ylab, ystrataname = yst.name, ystratalabs = yst.lab, ci = input$ci, timeby = input$timeby, xlims = input$xlims, ylims = input$ylims,
+              cumhaz = input$cumhaz, cluster.option = "None", cluster.var = NULL, data = data.km, pval.coord = pval.coord, legendposition = legend.p, linecols = pal, xlabs = text.x, dashed = dashed, cut.landmark = cut.landmark,
+              showpercent = input$showpercent, surv.scale = surv.scale, status.cmprsk = status_cmprsk
             )
           )
         }
-      }
-        else {
+      } else {
         return(
           jskm::jskm(res.km,
             pval = input$pval, marks = input$marks, table = input$table, ylab = ylab, ystrataname = yst.name, ystratalabs = yst.lab, ci = input$ci, timeby = input$timeby, xlims = input$xlims, ylims = input$ylims,
             cumhaz = input$cumhaz, cluster.option = "cluster", cluster.var = id.cluster(), data = data.km, pval.coord = pval.coord, legendposition = legend.p, linecols = pal, xlabs = text.x, dashed = dashed, cut.landmark = cut.landmark,
-            showpercent = input$showpercent, surv.scale = surv.scale, status.cmprsk =  status_cmprsk
+            showpercent = input$showpercent, surv.scale = surv.scale, status.cmprsk = status_cmprsk
           )
         )
       }
